==> core_models-0.2.2.gem: app/controllers/core_models/i18n/languages_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::LanguagesController < CoreModelsController
    # GET /i18n/languages
    # GET /i18n/languages.json
    def index
      @i18n_languages = I18n::Language.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_languages }
      end
    end

    # GET /i18n/languages/1
    # GET /i18n/languages/1.json
    def show
      @i18n_language = I18n::Language.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_language }
      end
    end

    # GET /i18n/languages/new
    # GET /i18n/languages/new.json
    def new
      @i18n_language = I18n::Language.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_language }
      end
    end

    # GET /i18n/languages/1/edit
    def edit
      @i18n_language = I18n::Language.find(params[:id])
    end

    # POST /i18n/languages
    # POST /i18n/languages.json
    def create
      @i18n_language = I18n::Language.new(params[:i18n_language])

      respond_to do |format|
        if @i18n_language.save
          format.html { redirect_to @i18n_language, :notice => 'Language was successfully created.' }
          format.json { render :json => @i18n_language, :status => :created, :location => @i18n_language }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/languages/1
    # PUT /i18n/languages/1.json
    def update
      @i18n_language = I18n::Language.find(params[:id])

      respond_to do |format|
        if @i18n_language.update_attributes(params[:i18n_language])
          format.html { redirect_to @i18n_language, :notice => 'Language was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/languages/1
    # DELETE /i18n/languages/1.json
    def destroy
      @i18n_language = I18n::Language.find(params[:id])
      @i18n_language.destroy

      respond_to do |format|
        format.html { redirect_to i18n_languages_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/i18n/languages_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class I18n::LanguagesController < CoreModelsController
    # GET /i18n/languages
    # GET /i18n/languages.json
    def index
      @i18n_languages = I18n::Language.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @i18n_languages }
      end
    end

    # GET /i18n/languages/1
    # GET /i18n/languages/1.json
    def show
      @i18n_language = I18n::Language.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @i18n_language }
      end
    end

    # GET /i18n/languages/new
    # GET /i18n/languages/new.json
    def new
      @i18n_language = I18n::Language.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @i18n_language }
      end
    end

    # GET /i18n/languages/1/edit
    def edit
      @i18n_language = I18n::Language.find(params[:id])
    end

    # POST /i18n/languages
    # POST /i18n/languages.json
    def create
      @i18n_language = I18n::Language.new(params[:i18n_language])

      respond_to do |format|
        if @i18n_language.save
          format.html { redirect_to @i18n_language, :notice => 'Language was successfully created.' }
          format.json { render :json => @i18n_language, :status => :created, :location => @i18n_language }
        else
          format.html { render :action => "new" }
          format.json { render :json => @i18n_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /i18n/languages/1
    # PUT /i18n/languages/1.json
    def update
      @i18n_language = I18n::Language.find(params[:id])

      respond_to do |format|
        if @i18n_language.update(params[:i18n_language])
          format.html { redirect_to @i18n_language, :notice => 'Language was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @i18n_language.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /i18n/languages/1
    # DELETE /i18n/languages/1.json
    def destroy
      @i18n_language = I18n::Language.find(params[:id])
      @i18n_language.destroy

      respond_to do |format|
        format.html { redirect_to i18n_languages_url }
        format.json { head :no_content }
      end
    end
  end
end
